@@ -8,7 +8,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2016 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -48,25 +48,26 @@ load_file(char const * fname)
     {
         struct stat stbf;
         if (fstat(fileno(fp), &stbf) != 0) {
+            int err = errno;
             fclose(fp);
+            errno = err;
             return NULL;
         }
 
         fsz = stbf.st_size;
-        res = (char*)AGALOC(fsz + 1, "load_file");
+        res = (char *)AGALOC(fsz + 1, "load_file");
         if (outfile_time < stbf.st_mtime)
             outfile_time = stbf.st_mtime;
+        if (maxfile_time < stbf.st_mtime)
+            maxfile_time = stbf.st_mtime;
     }
 
     {
         char * scan = res;
         do  {
             size_t sz = fread(scan, 1, fsz, fp);
-            if (sz == 0) {
-                fprintf(stderr, LD_EXTRACT_BAD_READ, errno, strerror(errno),
-                        (int)fsz, fname);
-                AG_ABEND(LD_EXTRACT_READ_FAIL);
-            }
+            if (sz == 0)
+                fserr(AUTOGEN_EXIT_FS_ERROR, "fread", fname);
 
             scan += sz;
             fsz  -= sz;
@@ -127,8 +128,8 @@ load_extract_file(char const * new_fil)
     }
 
     if (last_fname != NULL) {
-        AGFREE((void*)last_fname);
-        AGFREE((void*)file_text);
+        AGFREE(last_fname);
+        AGFREE(file_text);
         last_fname = file_text = NULL;
     }
 
@@ -141,10 +142,10 @@ load_extract_file(char const * new_fil)
     if (file_text != NULL)
         return file_text;
 
-    AGFREE((void*)last_fname);
+    AGFREE(last_fname);
     last_fname = NULL;
     if (file_text != NULL) {
-        AGFREE((void*)file_text);
+        AGFREE(file_text);
         file_text = NULL;
     }
     return NULL;
@@ -182,8 +183,8 @@ mk_empty_text(char const * start, char const * end, SCM def)
 static SCM
 get_text(char const * text, char const * start, char const * end, SCM def)
 {
-    char const* pzS = strstr(text, start);
-    char const* pzE;
+    char const * pzS = strstr(text, start);
+    char const * pzE;
 
     if (pzS == NULL)
         return mk_empty_text(start, end, def);
@@ -318,8 +319,8 @@ ag_scm_extract(SCM file, SCM marker, SCM caveat, SCM def)
              res = mk_empty_text(start, end, def);
         else res = get_text(text, start, end, def);
 
-        AGFREE((void*)start);
-        AGFREE((void*)end);
+        AGFREE(start);
+        AGFREE(end);
         return res;
     }
 }
@@ -353,7 +354,7 @@ ag_scm_find_file(SCM file, SCM suffix)
          *  The suffix is optional.  If provided, it will be a string.
          */
         if (AG_SCM_STRING_P(suffix)) {
-            char* apz[2];
+            char * apz[2];
             apz[0] = (char *)ag_scm2zchars(suffix, "file suffix");
             apz[1] = NULL;
             if (SUCCESSFUL(find_file(pz, z, (char const **)apz, NULL)))
